@@ -444,6 +444,7 @@ xfsm_legacy_perform_session_save (void)
         {
           struct timeval tv;
           fd_set fds;
+          fd_set exceptfds;
           int msecs;
           int fd;
           int ret;
@@ -455,9 +456,11 @@ xfsm_legacy_perform_session_save (void)
           fd = ConnectionNumber (display);
           FD_ZERO (&fds);
           FD_SET (fd, &fds);
+          FD_ZERO (&exceptfds);
+          FD_SET (fd, &exceptfds);
           tv.tv_sec = (WM_SAVE_YOURSELF_TIMEOUT - msecs) / 1000;
           tv.tv_usec = ((WM_SAVE_YOURSELF_TIMEOUT - msecs) % 1000) * 1000;
-          ret = select (fd + 1, &fds, NULL, &fds, &tv);
+          ret = select (fd + 1, &fds, NULL, &exceptfds, &tv);
           if (ret == -1)
             {
               perror ("select");
@@ -629,8 +632,7 @@ xfsm_legacy_startup (void)
 
   for (lp = restart_apps; lp != NULL; lp = lp->next)
     {
-      screen = gdk_display_get_screen (gdk_display_get_default (),
-                                       SM_RESTART_APP (lp->data)->screen_num);
+      screen = gdk_screen_get_default ();
       xfsm_start_application (SM_RESTART_APP (lp->data)->command, NULL,
                               screen, NULL, NULL, NULL);
       g_strfreev (SM_RESTART_APP (lp->data)->command);
@@ -667,6 +669,3 @@ xfsm_legacy_shutdown (void)
   gdk_error_trap_pop_ignored ();
 #endif
 }
-
-
-
